#!/usr/bin/python

import datetime 
import re
import subprocess

MANUAL_BRANCH = 'latest'

def shell_value( args ):
    if isinstance( args , str ):
        r = re.compile( "\s+" )
        args = r.split( args )
    p = subprocess.Popen( args , stdout=subprocess.PIPE , stderr=subprocess.PIPE )
    r = p.communicate()
    value = r[0].decode().rstrip()
    return value

def get_manual_path():
    branch = shell_value('git symbolic-ref HEAD').split('/')[2]
    if branch == MANUAL_BRANCH:
        manual_path = MANUAL_BRANCH
    else:
        manual_path = branch

    return manual_path

def get_commit():
    return shell_value('git rev-parse --verify HEAD')

def get_branch():
    return shell_value('git symbolic-ref HEAD').split('/')[2]

def main():
    BREAK = "\n"

    print("MongoDB Manual:" + BREAK +
          "     Commit: " + meta_commit() + BREAK +
          "     Branch: " + meta_branch() + BREAK + 
          "     Year: " + str(datetime.date.today().year))

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
#
# MongoDB documentation build configuration file, created by
# sphinx-quickstart on Mon Oct  3 09:58:40 2011.
#
# This file is execfile()d with the current directory set to its containing dir.

# All configuration values have a default; values that are commented out
# serve to show the default.

import sys, os
import datetime
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "bin")))

import mongodb_docs_meta

meta = {
    'branch': mongodb_docs_meta.get_branch(),
    'commit': mongodb_docs_meta.get_commit(),
    'manual_path': mongodb_docs_meta.get_manual_path(),
    'date': str(datetime.date.today().year),
}

# -- General configuration ----------------------------------------------------

needs_sphinx = '1.0'

extensions = ["sphinx.ext.intersphinx", "sphinx.ext.extlinks", "mongodb_domain", "additional_directives"]

templates_path = ['.templates']
source_suffix = '.txt'
master_doc = 'contents'

project = u'MongoDB Meta Driver'
copyright = u'2012-' + meta['date'] + ', 10gen, Inc.'

version = '0.1'
release = version + '-dev'

current_git_commit = meta['commit']
current_git_branch = meta['branch']

rst_epilog = ".. |branch| replace:: ``" + current_git_branch + "``" + """
.. |commit| replace:: ``""" + current_git_commit + "``" + """
.. |copy| unicode:: U+000A9
.. |hardlink| replace:: http://docs.mongodb.org/""" + current_git_branch

exclude_patterns = []
composite_pages = []
pygments_style = 'sphinx'

extlinks = {
    'manual': ('https://docs.mongodb.org/manual%s', '' ),
    'issue': ('https://jira.mongodb.org/browse/%s', '' ),
    'wiki': ('http://www.mongodb.org/display/DOCS/%s', ''),
    'api': ('http://api.mongodb.org/%s', ''),
    'source': ('https://github.com/mongodb/mongo/blob/master/%s', ''),
    'docsgithub' : ( 'http://github.com/mongodb/mongo-meta-driver/blob/' + current_git_branch + '/%s', ''),
    'hardlink' : ( 'http://docs.mongodb.org/meta-driver/' + current_git_branch + '/%s', '')
}

intersphinx_mapping = {
    'pymongo': ('http://api.mongodb.org/python/current/', None),
    'mongodb': ('http://docs.mongodb.org/manual/', None)
}

# -- Options for HTML output ---------------------------------------------------

html_theme = 'mongodb'
html_theme_path = ['themes']

html_title = project + ' Manual'

html_logo = "source/.static/logo-mongodb.png"
html_static_path = ['source/.static']

html_last_updated_fmt = '%b %d, %Y'

html_copy_source = False
html_use_smartypants = True
html_domain_indices = True
html_use_index = True
html_split_index = False
html_show_sourcelink = False
html_show_sphinx = True
html_show_copyright = True
htmlhelp_basename = 'MongoDBdoc'

manual_edition_path = 'http://docs.mongodb.org/meta-driver/' + current_git_branch + '/' + project + '-Manual-' + current_git_branch

html_theme_options = {
    'branch': current_git_branch,
    'pdfpath':  manual_edition_path + '.pdf',
    'epubpath':  manual_edition_path + '.epub',
    'manual_path': meta['manual_path'],
    'repo_name': "mongo-meta-driver",
    'jira_project': 'DOCS',
    'google_analytics': 'UA-7301842-8',
    'project': 'meta-driver'
}

html_sidebars = {
    '**': ['pagenav.html', 'intrasites.html'],
}


# -- Options for LaTeX output --------------------------------------------------

latex_documents = [
#   (source start file, target name, title, author, documentclass [howto/manual]),
]

latex_elements = {
    'preamble': '\DeclareUnicodeCharacter{FF04}{\$} \DeclareUnicodeCharacter{FF0E}{.} \PassOptionsToPackage{hyphens}{url}',
    'pointsize': '10pt',
    'papersize': 'letterpaper'
}

latex_use_parts = True
latex_show_pagerefs = True
latex_show_urls = False
latex_domain_indices = True

# -- Options for manual page output --------------------------------------------

man_pages = [
  # (source start file, name, description, authors, manual section),
]


# -- Options for Epub output ---------------------------------------------------

# Bibliographic Dublin Core info.
epub_title = u'MongoDB'
epub_author = u'MongoDB Documentation Project'
epub_publisher = u'MongoDB Documentation Project'
epub_copyright = u'2012-' + meta['date'] + ', 10gen Inc.'
epub_theme = 'epub_mongodb'
epub_tocdup = True
epub_tocdepth = 3
epub_language = 'en'
epub_scheme = 'url'
epub_identifier = 'http://docs.mongodb.org/' + current_git_branch
epub_exclude_files = []

epub_pre_files = []
epub_post_files = []



from docutils.parsers.rst import Directive, directives
from docutils import nodes
from sphinx.locale import _
from sphinx.util.compat import Directive, make_admonition
from sphinx import addnodes

class MongoDBNode(Directive):
    """
    An custom admonition for the MongoDB Manual.
    """
    has_content = True
    required_arguments = 0
    optional_arguments = 1
    final_argument_whitespace = True
    option_spec = {}
    is_seealso = False
    is_related = False

    def run(self):
        if self.is_seealso:
            ret = make_admonition(addnodes.seealso, self.name, [_('See')], self.options,
                                  self.content, self.lineno, self.content_offset, self.block_text,
                                  self.state, self.state_machine)
        elif self.is_related:
            ret = make_admonition(addnodes.seealso, self.name, [_('Related')], self.options,
                                  self.content, self.lineno, self.content_offset, self.block_text,
                                  self.state, self.state_machine)
        else:
            ret = make_admonition(optional_node, self.name, self.directive_name, self.options,
                                  self.content, self.lineno, self.content_offset,
                                  self.block_text, self.state, self.state_machine)

        if self.arguments:
            argnodes, msgs = self.state.inline_text(self.arguments[0],
                                                    self.lineno)
            para = nodes.paragraph()
            para += argnodes
            para += msgs
            ret[0].insert(1, para)
        return ret

def visit_mongodb_node(self, node):
    self.visit_admonition(node)

def depart_mongodb_node(self, node):
    self.depart_admonition(node)

def mongodb_add_node(app, type):
    app.add_node(type,
                 html=(visit_mongodb_node, depart_mongodb_node),
                 latex=(visit_mongodb_node, depart_mongodb_node),
                 text=(visit_mongodb_node, depart_mongodb_node),
                 man=(visit_mongodb_node, depart_mongodb_node),
                 texinfo=(visit_mongodb_node, depart_mongodb_node))

################################################################################

class optional_node(nodes.Admonition, nodes.Element): pass

class example_node(nodes.Admonition, nodes.Element): pass

class Optional(MongoDBNode):
    directive_name = ["Optional"]

class Example(MongoDBNode):
    directive_name = ["Example"]

class See(MongoDBNode):
    is_seealso = True
    directive_name = ["See"]

class Related(MongoDBNode):
    is_related = True
    directive_name = ["Related"]

def setup(app):
    app.add_directive('optional', Optional)
    app.add_directive('see', See)
    app.add_directive('related', Related)
    app.add_directive('example', Example)

    mongodb_add_node(app, optional_node)
    mongodb_add_node(app, example_node)
